﻿IF NOT EXISTS (SELECT 1 FROM SysLic)
	RETURN;

--region Save SysSettings
IF OBJECT_ID('UpdatedSysSettingsLog') IS NOT NULL
	DROP TABLE UpdatedSysSettingsLog;

CREATE TABLE UpdatedSysSettingsLog (
	Id UNIQUEIDENTIFIER NOT NULL DEFAULT (NEWID()),
	Name NVARCHAR(250) NOT NULL DEFAULT (''),
	ValueTypeName NVARCHAR(250) NOT NULL DEFAULT (''),
	IsPersonal BIT NOT NULL DEFAULT (0),
	IsCacheable BIT NOT NULL DEFAULT (0),
	SysFolderId UNIQUEIDENTIFIER NULL,
	Code NVARCHAR(50) NOT NULL DEFAULT (''),
	Description NVARCHAR(250) NOT NULL DEFAULT (''),
	ReferenceSchemaUId UNIQUEIDENTIFIER NULL,
	IsSSPAvailable BIT NOT NULL DEFAULT (0),
	CreatedOn DATETIME2(3) DEFAULT (GETUTCDATE())
);

IF OBJECT_ID('CheckSysSettingsUpdate') IS NOT NULL
	DROP TRIGGER CheckSysSettingsUpdate;

DECLARE @cmdSysSettingsCreateTrigger NVARCHAR(MAX) =
'CREATE TRIGGER CheckSysSettingsUpdate
ON SysSettings
AFTER UPDATE
AS
BEGIN
	SET NOCOUNT ON;
	INSERT INTO UpdatedSysSettingsLog
		(Id, Name, ValueTypeName, IsPersonal, IsCacheable, SysFolderId, Code, Description, ReferenceSchemaUId, IsSSPAvailable)
	SELECT
		Id, Name, ValueTypeName, IsPersonal, IsCacheable, SysFolderId, Code, Description, ReferenceSchemaUId, IsSSPAvailable
	FROM DELETED;
END';
EXEC (@cmdSysSettingsCreateTrigger);
--endregion

--region Save SysSettings values
IF OBJECT_ID('UpdatedSysSettingsValuesLog') IS NOT NULL
	DROP TABLE UpdatedSysSettingsValuesLog;

CREATE TABLE UpdatedSysSettingsValuesLog (
	Id UNIQUEIDENTIFIER NOT NULL DEFAULT (NEWID()),
	SysSettingsId UNIQUEIDENTIFIER NULL,
	SysAdminUnitId UNIQUEIDENTIFIER NULL,
	IsDef BIT NOT NULL DEFAULT (0),
	TextValue NVARCHAR(MAX) NOT NULL DEFAULT (''),
	IntegerValue INT NOT NULL DEFAULT (0),
	FloatValue DECIMAL(18, 2) NOT NULL DEFAULT (0),
	BooleanValue BIT NOT NULL DEFAULT (0),
	DateTimeValue DATETIME2(3) NULL,
	GuidValue UNIQUEIDENTIFIER NULL,
	BinaryValue VARBINARY(MAX) NULL,
	CreatedOn DATETIME2(3) DEFAULT (GETUTCDATE())
);

IF OBJECT_ID('CheckSysSettingsValueUpdate') IS NOT NULL
	DROP TRIGGER CheckSysSettingsValueUpdate;

DECLARE @cmdSysSettingsValueCreateTrigger NVARCHAR(MAX) =
'CREATE TRIGGER CheckSysSettingsValueUpdate
ON SysSettingsValue
AFTER UPDATE
AS
BEGIN
	SET NOCOUNT ON;
	INSERT INTO UpdatedSysSettingsValuesLog
		(Id, SysSettingsId, SysAdminUnitId, IsDef, TextValue, IntegerValue, FloatValue, BooleanValue, DateTimeValue, GuidValue, BinaryValue)
	SELECT
		Id, SysSettingsId, SysAdminUnitId, IsDef, TextValue, IntegerValue, FloatValue, BooleanValue, DateTimeValue, GuidValue, BinaryValue
	FROM DELETED;
END';
EXEC (@cmdSysSettingsValueCreateTrigger);
--endregion